@@ -346,6 +346,10 @@ class MSData:
             Size of the plot.
         """
 
+        # check if BPC data is ready
+        if len(self.rtBPC) is None:
+            self.getBPCData()
+
         plt.figure(figsize=figsize, dpi=dpi)
         plt.plot(self.rtBPC, self.intensityBPC, color="black", linewidth=1)
         plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=5)
